@@ -4,11 +4,10 @@ package String::Interpolate::RE;
 
 use strict;
 use warnings;
-use Carp;
 
 use Exporter::Shiny qw[ strinterp ];
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 ## no critic (ProhibitAccessOfPrivateData)
 
@@ -23,15 +22,19 @@ my %Opt = (
         recurse_fail_limit => 100,
 );
 
-my $default_strinterp;
+*strinterp =  _mk_strinterp( \%Opt );
+
+sub _croak {
+    require Carp;
+    goto &Carp::croak;
+}
 
 sub _generate_strinterp {
 
     my ( $me, $name, $args ) = @_;
 
-    if ( ! defined $args || ! defined $args->{opts}) {
-        return $default_strinterp || _mk_strinterp( \%Opt );
-    }
+    return \&strinterp
+      if ! defined $args || ! defined $args->{opts};
 
     my %opt = %Opt;
     $opt{lc $_} = $args->{opts}{$_} foreach keys %{$args->{opts}};
@@ -95,10 +98,7 @@ sub _strinterp {
               : $opt->{useenv} && exists $ENV{$t}   ? $ENV{$t}
 
               # undefined: throw an error?
-              : $opt->{raiseundef}                  ? croak( "undefined variable: $t\n" )
-
-              # undefined: replace with ''?
-              : $opt->{emptyundef}                  ? ''
+              : $opt->{raiseundef}                  ? _croak( "undefined variable: $t\n" )
 
               # undefined
               :                                     undef
@@ -111,7 +111,7 @@ sub _strinterp {
                 RECURSE:
                   {
 
-                      croak(
+                      _croak(
                           "circular interpolation loop detected with repeated interpolation of <\$$t>\n"
                       ) if $opt->{track}{$t}++;
 
@@ -119,7 +119,7 @@ sub _strinterp {
 
                       last RECURSE if $opt->{recurse_limit} && $opt->{loop} > $opt->{recurse_limit};
 
-                      croak(
+                      _croak(
                           "recursion fail-safe limit ($opt->{recurse_fail_limit}) reached at interpolation of <\$$t>\n"
                       ) if $opt->{recurse_fail_limit} && $opt->{loop} > $opt->{recurse_fail_limit};
 
@@ -131,8 +131,10 @@ sub _strinterp {
                   --$opt->{loop};
               }
 
-              # if not defined, just put it back into the string
-                 ! defined $v                     ? '$' . $1
+              # if not defined:
+              #   if emptyundef, replace with an empty string
+              #   otherwise,     just put it back into the string
+                 ! defined $v ? ( $opt->{emptyundef}  ? '' : '$' . $1 )
 
               # no format? return as is
               :  ! defined $3 || $3 eq ''         ? $v
@@ -157,6 +159,8 @@ sub _strinterp {
 #   The GNU General Public License, Version 3, June 2007
 #
 
+__END__
+
 =pod
 
 =head1 NAME
@@ -165,7 +169,7 @@ String::Interpolate::RE - interpolate variables into strings using regular expre
 
 =head1 VERSION
 
-version 0.09
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -330,10 +334,21 @@ interpolating nested variable values (with the C<recurse> option true ).
 
 =back
 
-=head1 BUGS AND LIMITATIONS
+=head1 SUPPORT
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=String-Interpolate-RE>.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-string-interpolate-re@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=String-Interpolate-RE
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/string-interpolate-re
+
+and may be cloned from
+
+  https://gitlab.com/djerius/string-interpolate-re.git
 
 =head1 AUTHOR
 
@@ -348,175 +363,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
-__END__
-
-
-#pod =head1 SYNOPSIS
-#pod
-#pod   # default formulation
-#pod   use String::Interpolate::RE qw( strinterp );
-#pod
-#pod   $str = strinterp( "${Var1} $Var2", $vars, \%opts );
-#pod
-#pod   # import with different default options.
-#pod   use String::Interpolate::RE strinterp => { opts => { useENV => 0 } };
-#pod
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod This module interpolates variables into strings using regular
-#pod expression matching rather than Perl's built-in interpolation
-#pod mechanism and thus hopefully does not suffer from the security
-#pod problems inherent in using B<eval> to interpolate into strings of
-#pod suspect ancestry.
-#pod
-#pod =head2 Changing the default option values
-#pod
-#pod The default values for L</strinterp>'s options were not all well
-#pod thought out.  B<String::Interpolate::RE> uses L<Exporter::Tiny>,
-#pod allowing a version of L</strinterp> with saner defaults to be
-#pod exported.  Simply specify them when importing:
-#pod
-#pod   use String::Interpolate::RE strinterp => { opts => { useENV => 0 } };
-#pod
-#pod The subroutine may be renamed using the C<-as> option:
-#pod
-#pod   use String::Interpolate::RE strinterp => { -as => strinterp_noenv,
-#pod                                              opts => { useENV => 0 } };
-#pod
-#pod   strinterp_noenv( ... );
-#pod
-#pod
-#pod =head1 INTERFACE
-#pod
-#pod =over
-#pod
-#pod =item strinterp
-#pod
-#pod     $str = strinterp( $template );
-#pod     $str = strinterp( $template, $vars );
-#pod     $str = strinterp( $template, $vars, \%opts );
-#pod
-#pod Interpolate variables into a template string, returning the
-#pod resultant string.  The template string is scanned for tokens of the
-#pod form
-#pod
-#pod     $VAR
-#pod     ${VAR}
-#pod
-#pod where C<VAR> is composed of one or more word characters (as defined by
-#pod the C<\w> Perl regular expression pattern). C<VAR> is resolved using
-#pod the optional C<$vars> argument, which may either by a hashref (in
-#pod which case C<VAR> must be a key), or a function reference (which is
-#pod passed C<VAR> as its only argument and must return the value).
-#pod
-#pod If the value returned for C<VAR> is defined, it will be interpolated
-#pod into the string at that point.  By default, variables which are not
-#pod defined are by default left as is in the string.
-#pod
-#pod The C<%opts> parameter may be used to modify the behavior of this
-#pod function.  The following (case insensitive) keys are recognized:
-#pod
-#pod =over
-#pod
-#pod =item format I<boolean>
-#pod
-#pod If this flag is true, the template string may provide a C<sprintf>
-#pod compatible format which will be used to generate the interpolated
-#pod value.  The format should be appended to the variable name with
-#pod an intervening C<:> character, e.g.
-#pod
-#pod     ${VAR:fmt}
-#pod
-#pod For example,
-#pod
-#pod     %var = ( foo => 3 );
-#pod     print strinterp( '${foo:%03d}', \%var, { format => 1 } );
-#pod
-#pod would result in
-#pod
-#pod     003
-#pod
-#pod
-#pod =item raiseundef I<boolean>
-#pod
-#pod If true, a variable which has not been defined will result in an
-#pod exception being raised.  This defaults to false.
-#pod
-#pod =item emptyundef I<boolean>
-#pod
-#pod If true, a variable which has not been defined will be replaced with
-#pod the empty string.  This defaults to false.
-#pod
-#pod =item useENV I<boolean>
-#pod
-#pod If true, the C<%ENV> hash will be searched for variables which are not
-#pod defined in the passed C<%var> hash.  This defaults to true.
-#pod
-#pod
-#pod =item recurse I<boolean>
-#pod
-#pod If true, derived values are themselves scanned for variables to
-#pod interpolate.  To specify a limit to the number of levels of recursions
-#pod to attempt, set the C<recurse_limit> option.  Circular dependencies
-#pod are caught, but just to be safe there's a limit of recursion levels
-#pod specified by C<recurse_fail_limit>, beyond which an exception is
-#pod thrown.
-#pod
-#pod For example,
-#pod
-#pod   my %var = ( a => '$b', b => '$c', c => 'd' );
-#pod   strinterp( '$a', \%var ) => '$b'
-#pod   strinterp( '$a', \%var, { recurse => 1 } ) => 'd'
-#pod   strinterp( '$a', \%var, { recurse => 1, recurse_limit => 1 } ) => '$c'
-#pod
-#pod   strinterp( '$a', { a => '$b', b => '$a' } , { recurse => 1 }
-#pod         recursive interpolation loop detected with repeated
-#pod         interpolation of $a
-#pod
-#pod =item recurse_limit I<integer>
-#pod
-#pod The number of recursion levels to descend when recursing into a
-#pod variable's value before stopping.  The default is C<0>, which means no
-#pod limit.
-#pod
-#pod =item recurse_fail_limit I<integer>
-#pod
-#pod The number of recursion levels to descend when recursing into a
-#pod variable's value before giving up and croaking.  The default is C<100>.
-#pod Setting this to C<0> means no limit.
-#pod
-#pod =item variable_re I<regular expression>
-#pod
-#pod This specifies the regular expression (created with the C<qr>
-#pod operator) which will match a variable name.  It defaults to
-#pod C<qr/\w+/>. Don't use C<:>, C<{>, or C<}> in the regex, or things may
-#pod break.
-#pod
-#pod =back
-#pod
-#pod =back
-#pod
-#pod
-#pod =head1 DIAGNOSTICS
-#pod
-#pod =over
-#pod
-#pod =item C<< undefined variable: %s >>
-#pod
-#pod This string is thrown if the C<RaiseUndef> option is set and the
-#pod variable C<%s> is not defined.
-#pod
-#pod =item C<< recursive interpolation loop detected with repeated interpolation of <%s> >>
-#pod
-#pod When resolving nested interpolated values (with the C<recurse> option
-#pod true ) a circular loop was found.
-#pod
-#pod =item C<< recursion fail-safe limit (%d) reached at interpolation of <%s> >>
-#pod
-#pod The recursion fail safe limit (C<recurse_fail_limit>) was reached while
-#pod interpolating nested variable values (with the C<recurse> option true ).
-#pod
-#pod =back
-#pod
